netapp_ontap.models.ip_interface_location API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.ip_interface_location`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class IpInterfaceLocationSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the IpInterfaceLocation object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `auto_revert: bool GET POST PATCH`

    The auto_revert field of the ip_interface_location.

  `broadcast_domain: BroadcastDomainSvm POST`

    The broadcast_domain field of the ip_interface_location.

  `failover: str GET POST PATCH`

    The failover field of the ip_interface_location.

  `home_node: Node GET POST PATCH`

    The home_node field of the ip_interface_location.

  `home_port: Port GET POST PATCH`

    The home_port field of the ip_interface_location.

  `is_home: bool GET PATCH`

    The is_home field of the ip_interface_location.

  `node: Node GET PATCH`

    The node field of the ip_interface_location.

  `port: Port GET PATCH`

    The port field of the ip_interface_location.